// clang-format off

ksNew (20,
       keyNew (PREFIX, KEY_VALUE, "@CONFIG_FILEPATH@", KEY_META, "array", "#2", KEY_END),
       keyNew (PREFIX "#0", KEY_VALUE, "You,", KEY_END),
       keyNew (PREFIX "#1", KEY_VALUE, "Me, &", KEY_END),
       keyNew (PREFIX "#2", KEY_VALUE, "The Violence", KEY_END),
       KS_END)
